@@ -48,7 +48,7 @@
       $cmd  = "gotmail";
     }
     if($curl_bin != "") {
-      $cmd .= " " . $curl_bin;
+      $cmd .= " --curl-bin" . $curl_bin;
     }
     if($gm_proxy != "") {
       $cmd .= " --proxy " . $gm_proxy;
